@@ -39,6 +39,9 @@ class DialerBackend(BaseBackend):
     def get_batch_max_seconds_to_send(self):
         return settings.DIALER_BATCH_MAX_SECONDS_TO_SEND
 
+    def get_retry_sending(self):
+        return settings.DIALER_RETRY_SENDING and self.is_turned_on_batch_sending()
+
     def create_message(self, recipient, content, related_objects, tag, template, is_autodialer=True, **kwargs):
         """
         Create dialer message which will be logged in the database.
